You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by si...@apache.org on 2012/02/27 23:55:51 UTC

svn commit: r1294379 [3/3] - in /commons/proper/chain/trunk: ./ apps/example1/src/main/java/org/apache/commons/chain/apps/example/ apps/example1/src/main/webapp/WEB-INF/ apps/example2/src/main/java/org/apache/commons/chain/apps/example/ apps/example2/s...

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/ExceptionCommand.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/ExceptionCommand.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/ExceptionCommand.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/ExceptionCommand.java Mon Feb 27 22:55:46 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.impl;
+package org.apache.commons.chain2.impl;
 
 
-import org.apache.commons.chain.Chain;
-import org.apache.commons.chain.Command;
-import org.apache.commons.chain.Context;
+import org.apache.commons.chain2.Chain;
+import org.apache.commons.chain2.Command;
+import org.apache.commons.chain2.Context;
 
 
 /**

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/ExceptionFilter.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/ExceptionFilter.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/ExceptionFilter.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/ExceptionFilter.java Mon Feb 27 22:55:46 2012
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.impl;
+package org.apache.commons.chain2.impl;
 
 
-import org.apache.commons.chain.Context;
-import org.apache.commons.chain.Filter;
+import org.apache.commons.chain2.Context;
+import org.apache.commons.chain2.Filter;
 
 
 /**

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/NonDelegatingCommand.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/NonDelegatingCommand.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/NonDelegatingCommand.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/NonDelegatingCommand.java Mon Feb 27 22:55:46 2012
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.impl;
+package org.apache.commons.chain2.impl;
 
 
-import org.apache.commons.chain.Command;
-import org.apache.commons.chain.Context;
+import org.apache.commons.chain2.Command;
+import org.apache.commons.chain2.Context;
 
 
 /**

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/NonDelegatingFilter.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/NonDelegatingFilter.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/NonDelegatingFilter.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/NonDelegatingFilter.java Mon Feb 27 22:55:46 2012
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.impl;
+package org.apache.commons.chain2.impl;
 
 
-import org.apache.commons.chain.Context;
-import org.apache.commons.chain.Filter;
+import org.apache.commons.chain2.Context;
+import org.apache.commons.chain2.Filter;
 
 
 /**

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/TestContext.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/TestContext.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/TestContext.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/TestContext.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.impl;
+package org.apache.commons.chain2.impl;
+
+import org.apache.commons.chain2.impl.ContextBase;
 
 
 /**

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/TestContextTestCase.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/TestContextTestCase.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/TestContextTestCase.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/impl/TestContextTestCase.java Mon Feb 27 22:55:46 2012
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.impl;
+package org.apache.commons.chain2.impl;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
-import org.apache.commons.chain.Context;
+import org.apache.commons.chain2.Context;
 import org.junit.Before;
 import org.junit.Test;
 

Copied: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/ChainResourcesTestCase.java (from r1294375, commons/proper/chain/trunk/src/test/java/org/apache/commons/chain/web/ChainResourcesTestCase.java)
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/ChainResourcesTestCase.java?p2=commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/ChainResourcesTestCase.java&p1=commons/proper/chain/trunk/src/test/java/org/apache/commons/chain/web/ChainResourcesTestCase.java&r1=1294375&r2=1294379&rev=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain/web/MockEnumeration.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/MockEnumeration.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web;
+package org.apache.commons.chain2.web;
 
 
 import java.util.Enumeration;

Copied: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/MockPrincipal.java (from r1294375, commons/proper/chain/trunk/src/test/java/org/apache/commons/chain/web/MockPrincipal.java)
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/MockPrincipal.java?p2=commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/MockPrincipal.java&p1=commons/proper/chain/trunk/src/test/java/org/apache/commons/chain/web/MockPrincipal.java&r1=1294375&r2=1294379&rev=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain/web/MockPrincipal.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/MockPrincipal.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web;
+package org.apache.commons.chain2.web;
 
 
 import java.security.Principal;

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/MockPortletContext.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/MockPortletContext.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/MockPortletContext.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/MockPortletContext.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.portlet;
+package org.apache.commons.chain2.web.portlet;
 
 
 import java.io.InputStream;

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/MockPortletRequest.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/MockPortletRequest.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/MockPortletRequest.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/MockPortletRequest.java Mon Feb 27 22:55:46 2012
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.portlet;
+package org.apache.commons.chain2.web.portlet;
 
 
 import javax.servlet.http.Cookie;
-import org.apache.commons.chain.web.MockEnumeration;
-import org.apache.commons.chain.web.MockPrincipal;
+
+import org.apache.commons.chain2.web.MockEnumeration;
+import org.apache.commons.chain2.web.MockPrincipal;
 
 import javax.portlet.PortalContext;
 import javax.portlet.PortletRequest;

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/MockPortletSession.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/MockPortletSession.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/MockPortletSession.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/MockPortletSession.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.portlet;
+package org.apache.commons.chain2.web.portlet;
 
 
 import java.util.Date;
@@ -25,7 +25,7 @@ import java.util.Map;
 import javax.portlet.PortletContext;
 import javax.portlet.PortletSession;
 
-import org.apache.commons.chain.web.MockEnumeration;
+import org.apache.commons.chain2.web.MockEnumeration;
 
 
 

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/PortletGetLocaleCommandTestCase.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/PortletGetLocaleCommandTestCase.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/PortletWebContextTestCase.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/PortletWebContextTestCase.java Mon Feb 27 22:55:46 2012
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.portlet;
+package org.apache.commons.chain2.web.portlet;
 
 import static org.junit.Assert.*;
 
-import org.apache.commons.chain.Context;
-import org.apache.commons.chain.impl.ContextBaseTestCase;
-import org.apache.commons.chain.web.WebContext;
+import org.apache.commons.chain2.Context;
+import org.apache.commons.chain2.impl.ContextBaseTestCase;
+import org.apache.commons.chain2.web.WebContext;
+import org.apache.commons.chain2.web.portlet.PortletWebContext;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ChainProcessorTestCase.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ChainProcessorTestCase.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ChainProcessorTestCase.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ChainProcessorTestCase.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.servlet;
+package org.apache.commons.chain2.web.servlet;
 
 import static org.junit.Assert.fail;
 
@@ -25,6 +25,7 @@ import java.io.ObjectOutputStream;
 
 import javax.servlet.ServletConfig;
 
+import org.apache.commons.chain2.web.servlet.ChainProcessor;
 import org.junit.Test;
 
 /**

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockHttpServletRequest.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockHttpServletRequest.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockHttpServletRequest.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockHttpServletRequest.java Mon Feb 27 22:55:46 2012
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.servlet;
+package org.apache.commons.chain2.web.servlet;
 
 
-import org.apache.commons.chain.web.MockEnumeration;
-import org.apache.commons.chain.web.MockPrincipal;
+import org.apache.commons.chain2.web.MockEnumeration;
+import org.apache.commons.chain2.web.MockPrincipal;
 
 import javax.servlet.RequestDispatcher;
 import javax.servlet.ServletInputStream;

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockHttpServletResponse.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockHttpServletResponse.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockHttpServletResponse.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockHttpServletResponse.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.servlet;
+package org.apache.commons.chain2.web.servlet;
 
 
 import javax.servlet.ServletOutputStream;

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockHttpSession.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockHttpSession.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockHttpSession.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockHttpSession.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.servlet;
+package org.apache.commons.chain2.web.servlet;
 
 
 import java.util.Enumeration;
@@ -25,7 +25,7 @@ import javax.servlet.ServletContext;
 import javax.servlet.http.HttpSession;
 import javax.servlet.http.HttpSessionContext;
 
-import org.apache.commons.chain.web.MockEnumeration;
+import org.apache.commons.chain2.web.MockEnumeration;
 
 
 

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockServletConfig.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockServletConfig.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockServletConfig.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockServletConfig.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.servlet;
+package org.apache.commons.chain2.web.servlet;
 
 import java.util.Enumeration;
 import java.util.HashMap;
@@ -23,7 +23,7 @@ import java.util.Map;
 import javax.servlet.ServletConfig;
 import javax.servlet.ServletContext;
 
-import org.apache.commons.chain.web.MockEnumeration;
+import org.apache.commons.chain2.web.MockEnumeration;
 
 /**
  * Mock {@link ServletConfig} implementation.

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockServletContext.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockServletContext.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockServletContext.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/MockServletContext.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.servlet;
+package org.apache.commons.chain2.web.servlet;
 
 
 import java.io.InputStream;

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ServletGetLocaleCommandTestCase.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ServletGetLocaleCommandTestCase.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ServletWebContextTestCase.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ServletWebContextTestCase.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.servlet;
+package org.apache.commons.chain2.web.servlet;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
@@ -36,9 +36,10 @@ import javax.servlet.http.HttpServletReq
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
 
-import org.apache.commons.chain.Context;
-import org.apache.commons.chain.impl.ContextBaseTestCase;
-import org.apache.commons.chain.web.WebContext;
+import org.apache.commons.chain2.Context;
+import org.apache.commons.chain2.impl.ContextBaseTestCase;
+import org.apache.commons.chain2.web.WebContext;
+import org.apache.commons.chain2.web.servlet.ServletWebContext;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;

Modified: commons/proper/chain/trunk/src/test/resources/org/apache/commons/chain2/config/test-config-2.xml
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/resources/org/apache/commons/chain2/config/test-config-2.xml?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/resources/org/apache/commons/chain2/config/test-config-2.xml (original)
+++ commons/proper/chain/trunk/src/test/resources/org/apache/commons/chain2/config/test-config-2.xml Mon Feb 27 22:55:46 2012
@@ -18,23 +18,23 @@
 
   <!-- Define command and chain aliases -->
   <define    name="adding-command"
-        className="org.apache.commons.chain.impl.AddingCommand"/>
+        className="org.apache.commons.chain2.impl.AddingCommand"/>
   <define    name="delegating-command"
-        className="org.apache.commons.chain.impl.DelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.DelegatingCommand"/>
   <define    name="delegating-filter"
-        className="org.apache.commons.chain.impl.DelegatingFilter"/>
+        className="org.apache.commons.chain2.impl.DelegatingFilter"/>
   <define    name="exception-command"
-        className="org.apache.commons.chain.impl.ExceptionCommand"/>
+        className="org.apache.commons.chain2.impl.ExceptionCommand"/>
   <define    name="exception-filter"
-        className="org.apache.commons.chain.impl.ExceptionFilter"/>
+        className="org.apache.commons.chain2.impl.ExceptionFilter"/>
   <define    name="non-delegating-command"
-        className="org.apache.commons.chain.impl.NonDelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.NonDelegatingCommand"/>
   <define    name="non-delegating-filter"
-        className="org.apache.commons.chain.impl.NonDelegatingFilter"/>
+        className="org.apache.commons.chain2.impl.NonDelegatingFilter"/>
   <define    name="test-chain"
-        className="org.apache.commons.chain.config.TestChain"/>
+        className="org.apache.commons.chain2.config.TestChain"/>
   <define    name="test-command"
-        className="org.apache.commons.chain.config.TestCommand"/>
+        className="org.apache.commons.chain2.config.TestCommand"/>
 
   <!-- Single command "chains" from CatalogBaseTestCase -->
   <adding-command

Modified: commons/proper/chain/trunk/src/test/resources/org/apache/commons/chain2/config/test-config.xml
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/resources/org/apache/commons/chain2/config/test-config.xml?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/resources/org/apache/commons/chain2/config/test-config.xml (original)
+++ commons/proper/chain/trunk/src/test/resources/org/apache/commons/chain2/config/test-config.xml Mon Feb 27 22:55:46 2012
@@ -18,101 +18,101 @@
 
   <!-- Single command "chains" from CatalogBaseTestCase -->
   <command   name="AddingCommand"
-        className="org.apache.commons.chain.impl.AddingCommand"/>
+        className="org.apache.commons.chain2.impl.AddingCommand"/>
   <command   name="DelegatingCommand"
-        className="org.apache.commons.chain.impl.DelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.DelegatingCommand"/>
   <command   name="DelegatingFilter"
-        className="org.apache.commons.chain.impl.DelegatingFilter"/>
+        className="org.apache.commons.chain2.impl.DelegatingFilter"/>
   <command   name="ExceptionCommand"
-        className="org.apache.commons.chain.impl.ExceptionCommand"/>
+        className="org.apache.commons.chain2.impl.ExceptionCommand"/>
   <command   name="ExceptionFilter"
-        className="org.apache.commons.chain.impl.ExceptionFilter"/>
+        className="org.apache.commons.chain2.impl.ExceptionFilter"/>
   <command   name="NonDelegatingCommand"
-        className="org.apache.commons.chain.impl.NonDelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.NonDelegatingCommand"/>
   <command   name="NonDelegatingFilter"
-        className="org.apache.commons.chain.impl.NonDelegatingFilter"/>
+        className="org.apache.commons.chain2.impl.NonDelegatingFilter"/>
   <chain     name="ChainBase"
-        className="org.apache.commons.chain.config.TestChain"/>
+        className="org.apache.commons.chain2.config.TestChain"/>
 
   <!-- Configurable command with settable properties -->
   <command   name="Configurable"
-        className="org.apache.commons.chain.config.TestCommand"
+        className="org.apache.commons.chain2.config.TestCommand"
               foo="Foo Value"
               bar="Bar Value"/>
 
   <!-- Chains with nested commands -->
   <chain     name="Execute2a">
     <command   id="1"
-        className="org.apache.commons.chain.impl.DelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.DelegatingCommand"/>
     <command   id="2"
-        className="org.apache.commons.chain.impl.DelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.DelegatingCommand"/>
     <command   id="3"
-        className="org.apache.commons.chain.impl.NonDelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.NonDelegatingCommand"/>
   </chain>
   <chain     name="Execute2b">
     <command   id="1"
-        className="org.apache.commons.chain.impl.DelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.DelegatingCommand"/>
     <command   id="2"
-        className="org.apache.commons.chain.impl.DelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.DelegatingCommand"/>
     <command   id="3"
-        className="org.apache.commons.chain.impl.DelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.DelegatingCommand"/>
   </chain>
   <chain     name="Execute2c">
     <command   id="1"
-        className="org.apache.commons.chain.impl.DelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.DelegatingCommand"/>
     <command   id="2"
-        className="org.apache.commons.chain.impl.DelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.DelegatingCommand"/>
     <command   id="3"
-        className="org.apache.commons.chain.impl.ExceptionCommand"/>
+        className="org.apache.commons.chain2.impl.ExceptionCommand"/>
   </chain>
   <chain      name="Execute2d">
     <command   id="1"
-        className="org.apache.commons.chain.impl.DelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.DelegatingCommand"/>
     <command   id="2"
-        className="org.apache.commons.chain.impl.ExceptionCommand"/>
+        className="org.apache.commons.chain2.impl.ExceptionCommand"/>
     <command   id="3"
-        className="org.apache.commons.chain.impl.NonDelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.NonDelegatingCommand"/>
   </chain>
   <chain      name="Execute4a">
     <command   id="1"
               id2="a"
-        className="org.apache.commons.chain.impl.DelegatingFilter"/>
+        className="org.apache.commons.chain2.impl.DelegatingFilter"/>
     <command   id="2"
-        className="org.apache.commons.chain.impl.DelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.DelegatingCommand"/>
     <command   id="3"
               id2="c"
-        className="org.apache.commons.chain.impl.NonDelegatingFilter"/>
+        className="org.apache.commons.chain2.impl.NonDelegatingFilter"/>
   </chain>
   <chain      name="Execute4b">
     <command   id="1"
-        className="org.apache.commons.chain.impl.DelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.DelegatingCommand"/>
     <command   id="2"
               id2="b"
-        className="org.apache.commons.chain.impl.DelegatingFilter"/>
+        className="org.apache.commons.chain2.impl.DelegatingFilter"/>
     <command   id="3"
-        className="org.apache.commons.chain.impl.DelegatingCommand"/>
+        className="org.apache.commons.chain2.impl.DelegatingCommand"/>
   </chain>
   <chain      name="Execute4c">
     <command   id="1"
               id2="a"
-        className="org.apache.commons.chain.impl.DelegatingFilter"/>
+        className="org.apache.commons.chain2.impl.DelegatingFilter"/>
     <command   id="2"
               id2="b"
-        className="org.apache.commons.chain.impl.DelegatingFilter"/>
+        className="org.apache.commons.chain2.impl.DelegatingFilter"/>
     <command   id="3"
               id2="c"
-        className="org.apache.commons.chain.impl.ExceptionFilter"/>
+        className="org.apache.commons.chain2.impl.ExceptionFilter"/>
   </chain>
   <chain      name="Execute4d">
     <command   id="1"
               id2="a"
-        className="org.apache.commons.chain.impl.DelegatingFilter"/>
+        className="org.apache.commons.chain2.impl.DelegatingFilter"/>
     <command   id="2"
               id2="b"
-        className="org.apache.commons.chain.impl.ExceptionFilter"/>
+        className="org.apache.commons.chain2.impl.ExceptionFilter"/>
     <command   id="3"
               id2="c"
-        className="org.apache.commons.chain.impl.NonDelegatingFilter"/>
+        className="org.apache.commons.chain2.impl.NonDelegatingFilter"/>
   </chain>
 
 </catalog>
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain/web/ChainResourcesTestCase.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/ChainResourcesTestCase.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web;
+package org.apache.commons.chain2.web;
 
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertNotNull;
@@ -22,12 +22,13 @@ import static org.junit.Assert.assertNot
 import java.util.Arrays;
 import java.util.Collection;
 
+import org.apache.commons.chain2.web.ChainResources;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameters;
 
 // Test case for org.apache.commons.chain.web.ChainResources
 
 @RunWith(Parameterized.class)
 public class ChainResourcesTestCase {
@@ -22,12 +22,13 @@ import static org.junit.Assert.assertNot
 import org.junit.runners.Parameterized.Parameters;
 
-// Test case for org.apache.commons.chain.web.ChainResources
+// Test case for org.apache.commons.chain2.web.ChainResources
 
 @RunWith(Parameterized.class)

Copied: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/MockEnumeration.java (from r1294375, commons/proper/chain/trunk/src/test/java/org/apache/commons/chain/web/MockEnumeration.java)
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/MockEnumeration.java?p2=commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/MockEnumeration.java&p1=commons/proper/chain/trunk/src/test/java/org/apache/commons/chain/web/MockEnumeration.java&r1=1294375&r2=1294379&rev=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/PortletGetLocaleCommandTestCase.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/PortletGetLocaleCommandTestCase.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.portlet;
+package org.apache.commons.chain2.web.portlet;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
@@ -29,12 +29,14 @@ import javax.portlet.PortletRequest;
 import javax.portlet.PortletResponse;
 import javax.portlet.PortletSession;
 
+import org.apache.commons.chain2.web.portlet.PortletGetLocaleCommand;
+import org.apache.commons.chain2.web.portlet.PortletWebContext;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 
 
 // Test case for org.apache.commons.chain.web.portlet.PortletGetLocaleCommand
 
 public class PortletGetLocaleCommandTestCase {
 
@@ -29,12 +29,14 @@ import javax.portlet.PortletRequest;
 
 
-// Test case for org.apache.commons.chain.web.portlet.PortletGetLocaleCommand
+// Test case for org.apache.commons.chain2.web.portlet.PortletGetLocaleCommand
 
 public class PortletGetLocaleCommandTestCase {

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/PortletWebContextTestCase.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/portlet/PortletWebContextTestCase.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ServletGetLocaleCommandTestCase.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ServletGetLocaleCommandTestCase.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.servlet;
+package org.apache.commons.chain2.web.servlet;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
@@ -29,12 +29,14 @@ import javax.servlet.http.HttpServletReq
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
 
+import org.apache.commons.chain2.web.servlet.ServletGetLocaleCommand;
+import org.apache.commons.chain2.web.servlet.ServletWebContext;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 
 
 // Test case for org.apache.commons.chain.web.servlet.ServletGetLocaleCommand
 
 public class ServletGetLocaleCommandTestCase {
 
@@ -29,12 +29,14 @@ import javax.servlet.http.HttpServletReq
 
 
-// Test case for org.apache.commons.chain.web.servlet.ServletGetLocaleCommand
+// Test case for org.apache.commons.chain2.web.servlet.ServletGetLocaleCommand
 
 public class ServletGetLocaleCommandTestCase {

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ServletSetLocaleCommandTestCase.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ServletSetLocaleCommandTestCase.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================
--- commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ServletSetLocaleCommandTestCase.java (original)
+++ commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ServletSetLocaleCommandTestCase.java Mon Feb 27 22:55:46 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.chain.web.servlet;
+package org.apache.commons.chain2.web.servlet;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
@@ -28,12 +28,14 @@ import javax.servlet.http.HttpServletReq
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
 
+import org.apache.commons.chain2.web.servlet.ServletSetLocaleCommand;
+import org.apache.commons.chain2.web.servlet.ServletWebContext;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 
 
 // Test case for org.apache.commons.chain.web.servlet.ServletSetLocaleCommand
 
 public class ServletSetLocaleCommandTestCase {
 
@@ -28,12 +28,14 @@ import javax.servlet.http.HttpServletReq
 
 
-// Test case for org.apache.commons.chain.web.servlet.ServletSetLocaleCommand
+// Test case for org.apache.commons.chain2.web.servlet.ServletSetLocaleCommand
 
 public class ServletSetLocaleCommandTestCase {

Modified: commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ServletWebContextTestCase.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/src/test/java/org/apache/commons/chain2/web/servlet/ServletWebContextTestCase.java?rev=1294379&r1=1294375&r2=1294379&view=diff
==============================================================================